Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Fukhaut <turjuque@gmail.com>2016-05-31 19:08:18 +0300
committerClément Fukhaut <turjuque@gmail.com>2016-05-31 19:08:18 +0300
commitd7d0166386b323756d7751816cdbc6e26224a7cc (patch)
tree5a6236a986a26c2c49febd6ee99d10f7c973529b /source/blender/gpu/intern/gpu_codegen.c
parent6ebbef4724dd7d6f09677d5cd871042a44f8008c (diff)
-Fixed SSR : Using depth buffer for increased precision but using another slot
-Fixed some typos
Diffstat (limited to 'source/blender/gpu/intern/gpu_codegen.c')
-rw-r--r--source/blender/gpu/intern/gpu_codegen.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/gpu/intern/gpu_codegen.c b/source/blender/gpu/intern/gpu_codegen.c
index d4c296ebd2f..f8f78566ea2 100644
--- a/source/blender/gpu/intern/gpu_codegen.c
+++ b/source/blender/gpu/intern/gpu_codegen.c
@@ -448,9 +448,9 @@ static void codegen_set_unique_ids(ListBase *nodes, bool reserve_texid)
GPUNode *node;
GPUInput *input;
GPUOutput *output;
/* XXX tex slot (texid) 0-9 are pbr textures */
/* TODO : these should reserved on demand not in bulk */
- int id = 1, texid = (reserve_texid) ? 9 : 0;
+ int id = 1, texid = (reserve_texid) ? 10 : 0;
bindhash = BLI_ghash_ptr_new("codegen_set_unique_ids1 gh");
definehash = BLI_ghash_ptr_new("codegen_set_unique_ids2 gh");
@@ -448,9 +448,9 @@ static void codegen_set_unique_ids(ListBase *nodes, bool reserve_texid)
GPUInput *input;
GPUOutput *output;
- /* XXX tex slot (texid) 0-9 are pbr textures */
+ /* XXX tex slot (texid) 0-10 are pbr textures */
/* TODO : these should reserved on demand not in bulk */